@@ -19,7 +19,7 @@ from ansible_collections.netapp.ontap.tests.unit.framework.mock_rest_and_zapi_re
 from ansible_collections.netapp.ontap.tests.unit.framework.rest_factory import rest_error_message, rest_responses
 from ansible_collections.netapp.ontap.tests.unit.framework.zapi_factory import build_zapi_error, build_zapi_response, zapi_responses
 from ansible_collections.netapp.ontap.plugins.modules.na_ontap_interface \
-    import NetAppOntapInterface as interface_module, netmask_length_to_netmask, netmask_to_netmask_length, main as my_main
+    import NetAppOntapInterface as interface_module, main as my_main
 
 
 if not netapp_utils.HAS_REQUESTS and sys.version_info < (2, 7):
@@ -30,7 +30,7 @@ if not netapp_utils.has_netapp_lib():
     pytestmark = pytest.mark.skip('skipping as missing required netapp_lib')
 
 
-def interface_info(dns=True):
+def interface_info(dns=True, address='2.2.2.2', netmask='1.1.1.1'):
     info = {
         'attributes-list': {
             'net-interface-info': {
@@ -44,8 +44,8 @@ def interface_info(dns=True):
                 'current-node': 'node',
                 'home-port': 'e0c',
                 'current-port': 'e0c',
-                'address': '2.2.2.2',
-                'netmask': '1.1.1.1',
+                'address': address,
+                'netmask': netmask,
                 'role': 'data',
                 'listen-for-dns-query': 'true',
                 'is-dns-update-enabled': 'true',
@@ -70,6 +70,7 @@ node_info = {
 
 ZRR = zapi_responses({
     'interface_info': build_zapi_response(interface_info(), 1),
+    'interface_ipv4': build_zapi_response(interface_info(address='10.10.10.13', netmask='255.255.255.0'), 1),
     'interface_info_no_dns': build_zapi_response(interface_info(dns=False), 1),
     'node_info': build_zapi_response(node_info, 1),
     'error_17': build_zapi_error(17, 'A LIF with the same name already exists'),
@@ -121,7 +122,7 @@ def test_successful_create():
         ('ZAPI', 'vserver-get-iter', ZRR['no_records']),
         ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'net-interface-get-iter', ZRR['no_records']),
-        ('ZAPI', 'net-interface-create', ZRR['success']),
+        ('ZAPI', 'net-interface-create', ZRR['success'])
     ])
     module_args = {
         'use_rest': 'never',
@@ -129,8 +130,8 @@ def test_successful_create():
         'home_node': 'node',
         'role': 'data',
         # 'subnet_name': 'subnet_name',
-        'address': 'address',
-        'netmask': 'netmask',
+        'address': '10.10.10.13',
+        'netmask': '255.255.255.0',
         'failover_policy': 'system-defined',
         'failover_group': 'failover_group',
         'firewall_policy': 'firewall_policy',
@@ -146,6 +147,29 @@ def test_successful_create():
     assert call_main(my_main, DEFAULT_ARGS, module_args)['changed']
 
 
+def test_modify_ip_subnet_cidr_mask():
+    ''' Test successful modify ip/subnet mask '''
+    register_responses([
+        ('ZAPI', 'vserver-get-iter', ZRR['no_records']),
+        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
+        ('ZAPI', 'net-interface-get-iter', ZRR['interface_info']),
+        ('ZAPI', 'net-interface-modify', ZRR['success']),
+        ('ZAPI', 'vserver-get-iter', ZRR['no_records']),
+        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
+        ('ZAPI', 'net-interface-get-iter', ZRR['interface_ipv4']),
+    ])
+    module_args = {
+        'use_rest': 'never',
+        'vserver': 'vserver',
+        'home_node': 'node',
+        'role': 'data',
+        'address': '10.10.10.13',
+        'netmask': '24'
+    }
+    assert call_main(my_main, DEFAULT_ARGS, module_args)['changed']
+    assert not call_main(my_main, DEFAULT_ARGS, module_args)['changed']
+
+
 def test_successful_create_for_NVMe():
     ''' Test successful create for NVMe protocol'''
     register_responses([
@@ -479,9 +503,11 @@ SRR = rest_responses({
         'name': 'abc_if',
         'uuid': '54321',
         'svm': {'name': 'vserver', 'uuid': 'svm_uuid'},
+        'dns_zone': 'netapp.com',
+        'ddns_enabled': True,
         'data_protocol': ['nfs'],
         'enabled': True,
-        'ip': {'address': '10.11.12.13', 'netmask': '255.192.0.0'},
+        'ip': {'address': '10.11.12.13', 'netmask': '10'},
         'location': {
             'home_port': {'name': 'e0c'},
             'home_node': {'name': 'node2'},
@@ -1024,16 +1050,6 @@ def test_rest_delete_idempotent_ip_no_svm():
     assert not call_main(my_main, DEFAULT_ARGS, module_args)['changed']
 
 
-def test_netmask_to_len():
-    # note the address has host bits set
-    assert netmask_to_netmask_length('10.10.10.10', '255.255.0.0') == '16'
-
-
-def test_len_to_netmask():
-    # note the address has host bits set
-    assert netmask_length_to_netmask('10.10.10.10', '16') == '255.255.0.0'
-
-
 def test_derive_fc_protocol_fcp():
     register_responses([
         ('GET', 'cluster', SRR['is_rest_97']),
@@ -1170,7 +1186,7 @@ def test_negative_derive_interface_type_unknown():
     register_responses([
         ('GET', 'cluster', SRR['is_rest_97']),
     ])
-    msg = "Error: Unexpected value(s) for protocols: ['unexpected']"
+    msg = "Error: unable to determine interface type, please set interface_type: unexpected value(s) for protocols: ['unexpected']"
     module_args = {
         'use_rest': 'always',
         'protocols': ['unexpected'],
@@ -1183,7 +1199,7 @@ def test_negative_derive_interface_type_multiple():
     register_responses([
         ('GET', 'cluster', SRR['is_rest_97']),
     ])
-    msg = "Error: Incompatible value(s) for protocols: ['fc-nvme', 'cifs']"
+    msg = "Error: unable to determine interface type, please set interface_type: incompatible value(s) for protocols: ['fc-nvme', 'cifs']"
     module_args = {
         'use_rest': 'always',
         'protocols': ['fc-nvme', 'cifs'],
@@ -1331,29 +1347,6 @@ def test_rest_auto_falls_back_to_zapi_if_ip_9_6():
     assert_warning_was_raised('Falling back to ZAPI: REST requires ONTAP 9.7 or later for interface APIs.')
 
 
-@patch('ansible_collections.netapp.ontap.plugins.modules.na_ontap_interface.HAS_IPADDRESS_LIB', False)
-def test_rest_auto_falls_back_to_zapi_if_ip_address_library_is_missing():
-    register_responses([
-        ('GET', 'cluster', SRR['is_rest_97'])
-    ])
-    module_args = {'use_rest': 'auto'}
-    # vserver is a required parameter with ZAPI
-    msg = "missing required argument with ZAPI: vserver"
-    assert msg in create_module(interface_module, DEFAULT_ARGS, module_args, fail=True)['msg']
-    print_warnings
-    assert_warning_was_raised('Falling back to ZAPI: the python ipaddress package is required for this module: None')
-
-
-@patch('ansible_collections.netapp.ontap.plugins.modules.na_ontap_interface.HAS_IPADDRESS_LIB', False)
-def test_rest_always_fail_if_ip_address_library_is_missing():
-    register_responses([
-        ('GET', 'cluster', SRR['is_rest_97'])
-    ])
-    module_args = {'use_rest': 'always'}
-    error = create_module(interface_module, DEFAULT_ARGS, module_args, fail=True)['msg']
-    assert error == 'Error: the python ipaddress package is required for this module: None'
-
-
 def test_fix_errors():
     register_responses([
         ('GET', 'cluster', SRR['is_rest_97'])
@@ -1564,7 +1557,7 @@ def test_error_messages_build_rest_body_and_validations():
     assert error in expect_and_capture_ansible_exception(my_obj.build_rest_body, 'fail')['msg']
     del my_obj.parameters['failover_group']
     my_obj.parameters['broadcast_domain'] = 'BDD1'
-    error = "Error: broadcast_domain is only supported for IP interfaces: abc_if, interface_type: fc"
+    error = "Error: broadcast_domain option only supported for IP interfaces: abc_if, interface_type: fc"
     assert error in expect_and_capture_ansible_exception(my_obj.build_rest_body, 'fail', None)['msg']
     my_obj.parameters['service_policy'] = 'svc_pol'
     error = "Error: 'service_policy' is not supported for FC interfaces."
@@ -1585,3 +1578,36 @@ def test_error_messages_build_rest_body_and_validations():
     my_obj.parameters['ipspace'] = 'ipspace'
     error = "Error: home_port and broadcast_domain are mutually exclusive for creating: abc_if"
     assert error in expect_and_capture_ansible_exception(my_obj.build_rest_body, 'fail', None)['msg']
+
+
+def test_dns_domain_ddns_enabled():
+    ''' domain and ddns enabled option test '''
+    register_responses([
+        ('GET', 'cluster', SRR['is_rest_9_9_1']),
+        ('GET', 'network/ip/interfaces', SRR['zero_records']),
+        ('GET', 'cluster/nodes', SRR['nodes']),
+        ('POST', 'network/ip/interfaces', SRR['success']),
+        ('GET', 'cluster', SRR['is_rest_9_9_1']),
+        ('GET', 'network/ip/interfaces', SRR['one_record_vserver']),
+        ('GET', 'cluster/nodes', SRR['nodes']),
+        ('PATCH', 'network/ip/interfaces/54321', SRR['success']),
+        ('GET', 'cluster', SRR['is_rest_9_9_1']),
+        ('GET', 'network/fc/interfaces', SRR['zero_records']),
+        ('GET', 'cluster', SRR['is_rest_9_9_0'])
+    ])
+    module_args = {
+        'use_rest': 'always',
+        'address': '10.11.12.13',
+        'netmask': '255.192.0.0',
+        'vserver': 'vserver',
+        'dns_domain_name': 'netapp1.com',
+        'is_dns_update_enabled': False
+    }
+    assert call_main(my_main, DEFAULT_ARGS, module_args)['changed']
+    assert call_main(my_main, DEFAULT_ARGS, module_args)['changed']
+    del module_args['address']
+    del module_args['netmask']
+    args = {'data_protocol': 'fc_nvme', 'home_node': 'my_node', 'protocols': 'fc-nvme', 'interface_type': 'fc'}
+    module_args.update(args)
+    assert 'dns_domain_name, is_dns_update_enabled options only supported for IP interfaces' in call_main(my_main, DEFAULT_ARGS, module_args, fail=True)['msg']
+    assert 'Error: Minimum version of ONTAP for is_dns_update_enabled is (9, 9, 1).' in call_main(my_main, DEFAULT_ARGS, module_args, fail=True)['msg']
